specktre
========

specktre is a tool for generating low-contrast desktop wallpapers from
tiling patterns.

Here are some examples of the patterns it produces:

.. image:: https://raw.githubusercontent.com/alexwlchan/specktre/development/output/demo.png

It can be used as a Python library, or invoked from the command-line.

Installation
************

To install specktre, run:

.. code-block:: console

   $ pip install specktre

Usage
*****

To see a usage message, just run:

.. code-block:: console

   $ specktre --help

There are some examples of specktre used as a script and as a library in
the ``examples`` directory in the `GitHub repo <https://github.com/alexwlchan/specktre>`_.

What's in a name?
*****************

The word "speckled" came to mind when describing this pattern, and I wrote
the first version shortly after the James Bond film *SPECTRE* had been
released.

License
*******

``specktre`` is licensed under the MIT License.  For more details, see the
``LICENSE`` file in the repository.
